summaryrefslogtreecommitdiffstats
path: root/slv2/plugin.h
diff options
context:
space:
mode:
authorDavid Robillard <d@drobilla.net>2007-04-28 00:44:32 +0000
committerDavid Robillard <d@drobilla.net>2007-04-28 00:44:32 +0000
commitcedf1a1f9e1e007aaf72757d896ed3455da10f69 (patch)
treeb1b2f1f36454dd0a019b5ec260f5911356d149cc /slv2/plugin.h
parenteda602d83c1a28f6a1654811affb00c78d25c8bf (diff)
downloadlilv-cedf1a1f9e1e007aaf72757d896ed3455da10f69.tar.gz
lilv-cedf1a1f9e1e007aaf72757d896ed3455da10f69.tar.bz2
lilv-cedf1a1f9e1e007aaf72757d896ed3455da10f69.zip
Reworked query/value system to expose data type.
git-svn-id: http://svn.drobilla.net/lad/slv2@475 a436a847-0d15-0410-975c-d299462d15a1
Diffstat (limited to 'slv2/plugin.h')
-rw-r--r--slv2/plugin.h26
1 files changed, 13 insertions, 13 deletions
diff --git a/slv2/plugin.h b/slv2/plugin.h
index 7ec073b..c6090a6 100644
--- a/slv2/plugin.h
+++ b/slv2/plugin.h
@@ -90,7 +90,7 @@ slv2_plugin_get_uri(SLV2Plugin plugin);
*
* Time = O(1)
*/
-SLV2Strings
+SLV2Values
slv2_plugin_get_data_uris(SLV2Plugin plugin);
@@ -133,13 +133,13 @@ slv2_plugin_get_class(SLV2Plugin plugin);
* <code>&lt;plugin-uri&gt; predicate ?object</code>
*
* May return NULL if the property was not found, or if object is not
* sensibly represented as an SLV2Strings (e.g. blank nodes).
*
* Return value must be freed by caller with slv2_strings_free.
*
* Time = Query
*/
-SLV2Strings
+SLV2Values
slv2_plugin_get_value(SLV2Plugin p,
const char* predicate);
@@ -154,13 +154,13 @@ slv2_plugin_get_value(SLV2Plugin p,
* (if information about it is contained in the plugin's data files).
*
* May return NULL if the property was not found, or if object is not
* sensibly represented as an SLV2Strings (e.g. blank nodes).
*
* Return value must be freed by caller with slv2_strings_free.
*
* Time = Query
*/
-SLV2Strings
+SLV2Values
slv2_plugin_get_value_for_subject(SLV2Plugin p,
const char* subject,
const char* predicate);
@@ -176,7 +176,7 @@ slv2_plugin_get_value_for_subject(SLV2Plugin p,
*
* Time = Query
*/
-SLV2Strings
+SLV2Values
slv2_plugin_get_properties(SLV2Plugin p);
@@ -189,7 +189,7 @@ slv2_plugin_get_properties(SLV2Plugin p);
*
* Time = Query
*/
-SLV2Strings
+SLV2Values
slv2_plugin_get_hints(SLV2Plugin p);
@@ -234,7 +234,7 @@ slv2_plugin_get_latency_port(SLV2Plugin p);
*
* Time = Query
*/
-SLV2Strings
+SLV2Values
slv2_plugin_get_supported_features(SLV2Plugin p);
@@ -245,7 +245,7 @@ slv2_plugin_get_supported_features(SLV2Plugin p);
*
* Time = Query
*/
-SLV2Strings
+SLV2Values
slv2_plugin_get_required_features(SLV2Plugin p);
@@ -257,7 +257,7 @@ slv2_plugin_get_required_features(SLV2Plugin p);
*
* Time = Query
*/
-SLV2Strings
+SLV2Values
slv2_plugin_get_optional_features(SLV2Plugin p);
@@ -270,7 +270,7 @@ slv2_plugin_get_optional_features(SLV2Plugin p);
*
* Time = Query
*/
-SLV2Strings
+SLV2Values
slv2_plugin_simple_query(SLV2Plugin plugin,
const char* sparql_str,
const char* variable);
@@ -133,13 +133,13 @@ slv2_plugin_get_class(SLV2Plugin plugin);
*
* May return NULL if the property was not found, or if object is not
- * sensibly represented as an SLV2Strings (e.g. blank nodes).
+ * sensibly represented as an SLV2Values (e.g. blank nodes).
*
@@ -133,13 +133,13 @@ slv2_plugin_get_class(SLV2Plugin plugin);
*
- * Return value must be freed by caller with slv2_strings_free.
+ * Return value must be freed by caller with slv2_values_free.
*
* Time = Query
@@ -154,13 +154,13 @@ slv2_plugin_get_value(SLV2Plugin p,
*
* May return NULL if the property was not found, or if object is not
- * sensibly represented as an SLV2Strings (e.g. blank nodes).
+ * sensibly represented as an SLV2Values (e.g. blank nodes).
*
@@ -154,13 +154,13 @@ slv2_plugin_get_value(SLV2Plugin p,
*
- * Return value must be freed by caller with slv2_strings_free.
+ * Return value must be freed by caller with slv2_values_free.
*
* Time = Query